@@ -45,7 +45,7 @@ AuthenticationLogMode::AuthenticationLogMode() :
 	
 	d->action = createDefaultAction();
 	d->action->setToolTip(i18n("Display the authentication log."));
-	d->action->setWhatsThis(i18n("Displays the authentication log in the current tab. This log displays all log in made by each user of the system, and can help you to know if someone tried to crack your system."));
+	d->action->setWhatsThis(i18n("Displays the authentication log in the current tab. This log displays all logins made by each user of the system, and can help you to know if someone tried to crack your system."));
 	
 }
 
